@@ -235,41 +235,39 @@ def flo_zhang_scatter_coeffs(degC, psu, theta, wlngth, delta=0.039):
     # a partial derivative of the natural logarithm of water activity with
     # regards to salinity.
     dlnawds = ne.evaluate(
-        '(-5.58651e-4 + 2.40452e-7 * degC - 3.12165e-9 * degC**2 + 2.40808e-11 * degC**3) +'
-        '1.5 * (1.79613e-5 - 9.9422e-8 * degC + 2.08919e-9 * degC**2 - 1.39872e-11 * degC**3) *'
-        'psu**0.5 + 2 * (-2.31065e-6 - 1.37674e-9 * degC - 1.93316e-11 * degC**2) * psu'
+        "(-5.58651e-4 + 2.40452e-7 * degC - 3.12165e-9 * degC**2 + 2.40808e-11 * degC**3) +"
+        "1.5 * (1.79613e-5 - 9.9422e-8 * degC + 2.08919e-9 * degC**2 - 1.39872e-11 * degC**3) *"
+        "psu**0.5 + 2 * (-2.31065e-6 - 1.37674e-9 * degC - 1.93316e-11 * degC**2) * psu"
     )
 
     # density derivative of refractive index from PMH model
     dfri = ne.evaluate(
-        '(nsw**2 - 1.0) * (1.0 + 2.0/3.0 * (nsw**2 + 2.0)'
-        '* (nsw/3.0 - 1.0/3.0 / nsw)**2)'
+        "(nsw**2 - 1.0) * (1.0 + 2.0/3.0 * (nsw**2 + 2.0)"
+        "* (nsw/3.0 - 1.0/3.0 / nsw)**2)"
     )
 
     # volume scattering at 90 degrees due to the density fluctuation
     beta_df = ne.evaluate(
-        'pi**2 / 2.0 * (wlngth*1e-9)**-4 * Kbz * degK * icomp '
-        '* dfri**2 * (6.0 + 6.0 * delta) / (6.0 - 7.0 * delta)'
+        "pi**2 / 2.0 * (wlngth*1e-9)**-4 * Kbz * degK * icomp "
+        "* dfri**2 * (6.0 + 6.0 * delta) / (6.0 - 7.0 * delta)"
     )
 
     # volume scattering at 90 degree due to the concentration fluctuation
-    flu_con = ne.evaluate('psu * M0 * dnds**2 / rho / -dlnawds / Na')
+    flu_con = ne.evaluate("psu * M0 * dnds**2 / rho / -dlnawds / Na")
     beta_cf = ne.evaluate(
-        '2.0 * pi**2 * (wlngth * 1e-9)**-4 * nsw**2 * flu_con'
-        '* (6.0 + 6.0 * delta) / (6.0 - 7.0 * delta)'
+        "2.0 * pi**2 * (wlngth * 1e-9)**-4 * nsw**2 * flu_con"
+        "* (6.0 + 6.0 * delta) / (6.0 - 7.0 * delta)"
     )
 
     # total volume scattering at 90 degree
     beta90sw = beta_df + beta_cf
 
     # total scattering coefficient of seawater (m-1)
-    bsw = ne.evaluate(
-        '8.0 * pi / 3.0 * beta90sw * ((2.0 + delta) / (1.0 + delta))'
-    )
+    bsw = ne.evaluate("8.0 * pi / 3.0 * beta90sw * ((2.0 + delta) / (1.0 + delta))")
 
     # total volume scattering coefficient of seawater (m-1 sr-1)
     betasw = ne.evaluate(
-        'beta90sw * (1.0 + ((1.0 - delta) / (1.0 + delta)) * cos(rad)**2)'
+        "beta90sw * (1.0 + ((1.0 - delta) / (1.0 + delta)) * cos(rad)**2)"
     )
 
     return betasw, bsw
@@ -287,8 +285,8 @@ def flo_refractive_index(wlngth, degC, psu):
     """
     # refractive index of air is from Ciddor (1996, Applied Optics).
     n_air = ne.evaluate(
-        '1.0 + (5792105.0 / (238.0185 - 1 / (wlngth/1e3)**2)'
-        '+ 167917.0 / (57.362 - 1 / (wlngth/1e3)**2)) / 1e8'
+        "1.0 + (5792105.0 / (238.0185 - 1 / (wlngth/1e3)**2)"
+        "+ 167917.0 / (57.362 - 1 / (wlngth/1e3)**2)) / 1e8"
     )
 
     # refractive index of seawater is from Quan and Fry (1994, Applied Optics)
@@ -303,14 +301,14 @@ def flo_refractive_index(wlngth, degC, psu):
     n8 = -4382.0
     n9 = 1.1455e6
     nsw = ne.evaluate(
-        'n0 + (n1 + n2 * degC + n3 * degC**2) * psu + n4 * degC**2'
-        '+ (n5 + n6 * psu + n7 * degC) / wlngth + n8 / wlngth**2'
-        '+ n9 / wlngth**3'
+        "n0 + (n1 + n2 * degC + n3 * degC**2) * psu + n4 * degC**2"
+        "+ (n5 + n6 * psu + n7 * degC) / wlngth + n8 / wlngth**2"
+        "+ n9 / wlngth**3"
     )
 
     # pure seawater
-    nsw = ne.evaluate('nsw * n_air')
-    dnds = ne.evaluate('(n1 + n2 * degC + n3 * degC**2 + n6 / wlngth) * n_air')
+    nsw = ne.evaluate("nsw * n_air")
+    dnds = ne.evaluate("(n1 + n2 * degC + n3 * degC**2 + n6 / wlngth) * n_air")
 
     return nsw, dnds
 
@@ -324,20 +322,19 @@ def flo_isotherm_compress(degC, psu):
     """
     # pure water secant bulk Millero (1980, Deep-sea Research)
     kw = ne.evaluate(
-        '19652.21 + 148.4206 * degC - 2.327105 * degC**2'
-        '+ 1.360477e-2 * degC**3 - 5.155288e-5 * degC**4'
+        "19652.21 + 148.4206 * degC - 2.327105 * degC**2"
+        "+ 1.360477e-2 * degC**3 - 5.155288e-5 * degC**4"
     )
 
     # seawater secant bulk
     a0 = ne.evaluate(
-        '54.6746 - 0.603459 * degC + 1.09987e-2 * degC**2'
-        '- 6.167e-5 * degC**3'
+        "54.6746 - 0.603459 * degC + 1.09987e-2 * degC**2" "- 6.167e-5 * degC**3"
     )
-    b0 = ne.evaluate('7.944e-2 + 1.6483e-2 * degC - 5.3009e-4 * degC**2')
-    ks = ne.evaluate('kw + a0 * psu + b0 * psu**1.5')
+    b0 = ne.evaluate("7.944e-2 + 1.6483e-2 * degC - 5.3009e-4 * degC**2")
+    ks = ne.evaluate("kw + a0 * psu + b0 * psu**1.5")
 
     # calculate seawater isothermal compressibility from the secant bulk
-    iso_comp = ne.evaluate('1 / ks * 1e-5')  # unit is Pa
+    iso_comp = ne.evaluate("1 / ks * 1e-5")  # unit is Pa
 
     return iso_comp
 
@@ -368,15 +365,14 @@ def flo_density_seawater(degC, psu):
 
     # density for pure water
     rho_w = ne.evaluate(
-        'b0 + b1 * degC + b2 * degC**2 + b3 * degC**3'
-        '+ b4 * degC**4 + b5 * degC**5'
+        "b0 + b1 * degC + b2 * degC**2 + b3 * degC**3" "+ b4 * degC**4 + b5 * degC**5"
     )
 
     # density for pure seawater
     rho_sw = ne.evaluate(
-        'rho_w + ((a0 + a1 * degC + a2 * degC**2'
-        '+ a3 * degC**3 + a4 * degC**4) * psu'
-        '+ (a5 + a6 * degC + a7 * degC**2) * psu**1.5 + a8 * psu**2)'
+        "rho_w + ((a0 + a1 * degC + a2 * degC**2"
+        "+ a3 * degC**3 + a4 * degC**4) * psu"
+        "+ (a5 + a6 * degC + a7 * degC**2) * psu**1.5 + a8 * psu**2)"
     )
 
     return rho_sw
@@ -400,7 +396,7 @@ def flo_scale_and_offset(counts_output, counts_dark, scale_factor):
     References:
         N/A
     """
-    value = ne.evaluate('(counts_output - counts_dark) * scale_factor')
+    value = ne.evaluate("(counts_output - counts_dark) * scale_factor")
     return value
 
 
