@@ -19,7 +19,7 @@ def process_files(file_str):
         files = np.sort(glob(file_str))
 
     if len(files) < 1:
-        raise FileNotFoundError('The provided string is not a file path')
+        raise FileNotFoundError("The provided string is not a file path")
     return files
 
 
@@ -31,32 +31,30 @@ def show_variables(files):
     i = len(files) // 2
 
     file = files[i]
-    print('information is based on file: {}'.format(file))
+    print("information is based on file: {}".format(file))
 
     variables = Dataset(file).variables
     info = {}
     for i, key in enumerate(variables):
         var = variables[key]
         info[i] = {
-            'name': key,
-            'dims': var.dimensions[0]
-            if len(var.dimensions) == 1
-            else 'string',
-            'units': '' if not hasattr(var, 'units') else var.units,
-            'comment': '' if not hasattr(var, 'comment') else var.comment,
+            "name": key,
+            "dims": var.dimensions[0] if len(var.dimensions) == 1 else "string",
+            "units": "" if not hasattr(var, "units") else var.units,
+            "comment": "" if not hasattr(var, "comment") else var.comment,
         }
 
     vars = DataFrame(info).T
 
     dim = vars.dims
-    dim[dim.str.startswith('str')] = 'string'
-    vars['dims'] = dim
+    dim[dim.str.startswith("str")] = "string"
+    vars["dims"] = dim
 
     vars = (
-        vars.sort_values(['dims', 'name'])
+        vars.sort_values(["dims", "name"])
         .reset_index(drop=True)
-        .loc[:, ['dims', 'name', 'units', 'comment']]
-        .set_index('name')
+        .loc[:, ["dims", "name", "units", "comment"]]
+        .set_index("name")
         .style
     )
 
@@ -89,13 +87,13 @@ def get_var_dim(files, key):
     elif len(unique_dims) == 1:
         return unique_dims[0]
     else:
-        return 'string'
+        return "string"
 
 
 def get_var_units(files, key):
-    from numpy import unique, nanargmax
+    from numpy import nanargmax, unique
 
-    units = [get_var_attrs(file, key, 'units') for file in files]
+    units = [get_var_attrs(file, key, "units") for file in files]
     units, counts = unique(units, return_counts=True)
     imax = nanargmax(counts)
 
@@ -133,7 +131,7 @@ def get_var_coords(files, key):
     """
     from numpy import concatenate
 
-    coords = set([get_var_attrs(f, key, 'coordinates') for f in files])
+    coords = set([get_var_attrs(f, key, "coordinates") for f in files])
     if None in coords:
         coords.remove(None)
     coords = [c.split() for c in coords]
@@ -223,7 +221,7 @@ def make_variable_dimension_dict(files, variable_names, n_check_files=3):
     dims = {}
     for key in variable_names:
         if not check_var_in_ncfiles(files_checklist, key):
-            msg = key + ' was not found in the files'
+            msg = key + " was not found in the files"
             warnings.warn(msg, GliderToolsWarning)
             continue
         single_dim = get_var_dim(files_checklist, key)
@@ -241,24 +239,25 @@ def make_variable_dimension_dict(files, variable_names, n_check_files=3):
     # get compulsory time and depth variables (if present)
     for d in dims:
         dim = dims[d]
-        if d == 'string':
+        if d == "string":
             continue
-        has_coord = any(['time' in v for v in dim])
+        has_coord = any(["time" in v for v in dim])
 
         if not has_coord:
-            coord = get_dim_coord(files_checklist, d, 'time')
+            coord = get_dim_coord(files_checklist, d, "time")
             if coord:
                 dims[d].update([coord])
             else:
-                msg = 'Could not find a time coordinate for dim: {}'.format(d)
+                msg = "Could not find a time coordinate for dim: {}".format(d)
                 warnings.warn(msg, GliderToolsWarning)
     return dims
 
 
 def read_nc_files_divevars(files, keys, verbose=True, return_skipped=False):
+    from os import path
+
     from numpy.ma import row_stack
     from pandas import DataFrame, concat
-    from os import path
 
     if not verbose:
         from numpy import arange as trange
@@ -266,7 +265,7 @@ def read_nc_files_divevars(files, keys, verbose=True, return_skipped=False):
         from tqdm import trange
 
     data = []
-    error = ''
+    error = ""
     skipped_files = []
     progress_bar = trange(len(files))
     d = 0
@@ -274,24 +273,22 @@ def read_nc_files_divevars(files, keys, verbose=True, return_skipped=False):
         fname = files[i]
         nc = Dataset(fname)
 
-        d = nc.dive_number if hasattr(nc, 'dive_number') else d + 1
+        d = nc.dive_number if hasattr(nc, "dive_number") else d + 1
 
         nc_keys = [k for k in filter(lambda k: k in nc.variables, keys)]
         if nc_keys:
             skipped = set(keys) - set(nc_keys)
             if skipped:
-                error += '{} not in {}\n'.format(
-                    str(skipped), path.split(fname)[1]
-                )
+                error += "{} not in {}\n".format(str(skipped), path.split(fname)[1])
             arr = row_stack([nc.variables[k][:] for k in nc_keys])
             nc.close()
 
             df = DataFrame(arr.T, columns=nc_keys)
-            df['dives'] = d
+            df["dives"] = d
             data += (df,)
         else:
             skipped_files += (fname,)
-            error += '{} was skipped\n'.format(fname)
+            error += "{} was skipped\n".format(fname)
 
     if len(error) > 0:
         print(error)
@@ -304,7 +301,7 @@ def read_nc_files_divevars(files, keys, verbose=True, return_skipped=False):
 
 
 def read_nc_files_strings(files, keys, verbose=True):
-    from numpy import r_, array
+    from numpy import array, r_
     from pandas import DataFrame
 
     if not verbose:
@@ -318,19 +315,19 @@ def read_nc_files_strings(files, keys, verbose=True):
     for i in trange(files.size):
         fname = files[i]
         nc = Dataset(fname)
-        d = nc.dive_number if hasattr(nc, 'dive_number') else d + 1
+        d = nc.dive_number if hasattr(nc, "dive_number") else d + 1
         arr = r_[[nc.variables[k][:].squeeze() for k in keys]]
         nc.close()
         data += (arr,)
         idx += (d,)
     df = DataFrame(array(data, dtype=str), columns=keys)
     for col in df:
-        df[col] = df[col].str.encode('ascii', 'ignore').str.decode('ascii')
+        df[col] = df[col].str.encode("ascii", "ignore").str.decode("ascii")
         try:
             df[col] = df[col].values.astype(float)
         except:
             pass
-    df['dives'] = idx
+    df["dives"] = idx
 
     return df
 
@@ -338,11 +335,11 @@ def read_nc_files_strings(files, keys, verbose=True):
 def process_time(files, df):
     def decode_times_1970(series):
         # DECODING TIMES IF PRESENT
-        t0 = np.datetime64('1970-01-01 00:00:00', 's')
+        t0 = np.datetime64("1970-01-01 00:00:00", "s")
 
         # realistic upper and lower limits since 1970
-        tmin = np.datetime64('2000-01-01 00:00:00', 's')
-        tmax = np.datetime64('2025-01-01 00:00:00', 's')
+        tmin = np.datetime64("2000-01-01 00:00:00", "s")
+        tmax = np.datetime64("2025-01-01 00:00:00", "s")
         lo_lim = (tmin - t0).astype(int)
         up_lim = (tmax - t0).astype(int)
 
@@ -350,10 +347,10 @@ def process_time(files, df):
         since1970 = ((series_masked > lo_lim) & (series_masked < up_lim)).all()
 
         if since1970:
-            dt = series.values.astype('timedelta64[s]')
-            return (t0 + dt).astype('datetime64[ns]')
+            dt = series.values.astype("timedelta64[s]")
+            return (t0 + dt).astype("datetime64[ns]")
 
-    time_cols = df.columns[['time' in col for col in df]].values.tolist()
+    time_cols = df.columns[["time" in col for col in df]].values.tolist()
     if isinstance(files, str):
         file = [files]
     else:
@@ -362,9 +359,9 @@ def process_time(files, df):
     if len(time_cols) > 0:
         for col in time_cols:
             units = get_var_units(file, col)
-            if units.startswith('seconds since 1970'):
-                df[col + '_dt64'] = decode_times_1970(df[col])
-                df = df.set_index(col + '_dt64', drop=False)
+            if units.startswith("seconds since 1970"):
+                df[col + "_dt64"] = decode_times_1970(df[col])
+                df = df.set_index(col + "_dt64", drop=False)
     return df
 
 
@@ -393,12 +390,12 @@ def process_dives(df):
             dives = dives + (updive / 2)
             return dives
 
-    depth_cols = df.columns[['depth' in col for col in df]].values.tolist()
-    time_cols = df.columns[['time' in col for col in df]].values.tolist()
-    if (len(depth_cols) > 0) & ('dives' in df):
+    depth_cols = df.columns[["depth" in col for col in df]].values.tolist()
+    time_cols = df.columns[["time" in col for col in df]].values.tolist()
+    if (len(depth_cols) > 0) & ("dives" in df):
         depth = df[depth_cols[0]]
         time = df[time_cols[0]]
-        df['dives'] = get_dives(time, depth, df.dives)
+        df["dives"] = get_dives(time, depth, df.dives)
 
     return df
 
@@ -436,7 +433,9 @@ def load_multiple_vars(
         missing data).
     """
     import time
+
     from pandas import DataFrame, to_numeric
+
     from ..utils import merge_dimensions
 
     # create a dictionary with dims as keys and variables as keys
@@ -450,21 +449,17 @@ def load_multiple_vars(
     # LOADING EACH DIMENSION
     for dim_name, var_names in dims_dict.items():
 
-        print(
-            '\nDIMENSION: {}\n{}'.format(dim_name, str(var_names)).replace(
-                "'", ''
-            )
-        )
+        print("\nDIMENSION: {}\n{}".format(dim_name, str(var_names)).replace("'", ""))
         time.sleep(0.2)  # to prevent progress bar interruption
         skipped_files = []
-        if dim_name == 'string':
+        if dim_name == "string":
             df = read_nc_files_strings(files, var_names, verbose)
         else:
             df, skipped_files = read_nc_files_divevars(
                 files, var_names, verbose, return_skipped=True
             )
         for col in df:
-            df[col] = to_numeric(df[col], errors='coerce')
+            df[col] = to_numeric(df[col], errors="coerce")
 
         # converting times that have 'seconds since 1970' units
         dim_files = list(set(files.tolist()) - set(skipped_files))
@@ -489,27 +484,25 @@ def load_multiple_vars(
     can_merge = len(merge_list) > 1
     if return_merged and can_merge:
         print(
-            '\nMerging dimensions on time indicies: {}, '.format(
-                merge_list[0]
-            ),
-            end='',
+            "\nMerging dimensions on time indicies: {}, ".format(merge_list[0]),
+            end="",
         )
         df_merged = data[merge_list.pop(0)]
         for other in merge_list:
-            if 'dives' in data[other]:
-                df_other = data[other].drop(columns='dives')
+            if "dives" in data[other]:
+                df_other = data[other].drop(columns="dives")
             else:
                 df_other = data[other]
-            print(other, end=', ')
+            print(other, end=", ")
             df_merged = merge_dimensions(df_merged, df_other, interp_lim=1)
-        data['merged'] = df_merged
-        drop_names = list(data['merged'].filter(regex='_drop').columns)
-        data['merged'] = data['merged'].drop(columns=drop_names)
+        data["merged"] = df_merged
+        drop_names = list(data["merged"].filter(regex="_drop").columns)
+        data["merged"] = data["merged"].drop(columns=drop_names)
 
     elif return_merged and (not can_merge):
         print(
-            '\nCannot merge data - not enough time indexed DataFrames'
-            '\nReturning unmerged dataframes'
+            "\nCannot merge data - not enough time indexed DataFrames"
+            "\nReturning unmerged dataframes"
         )
 
     # MAKING NETCDFS
@@ -522,8 +515,8 @@ def load_multiple_vars(
             index_name=key,
             attrs=netcdf_attrs,
         )
-        if 'dives' in data:
-            data = data.set_coords('dives')
+        if "dives" in data:
+            data = data.set_coords("dives")
 
     return data
 
@@ -531,14 +524,15 @@ def load_multiple_vars(
 def make_xr_dataset(
     df,
     files,
-    index_name='index',
+    index_name="index",
     attrs={},
     keep_variable_attrs=True,
     keep_global_attrs=False,
 ):
     import re
-    from xarray import open_dataset
+
     from pandas import Timestamp
+    from xarray import open_dataset
 
     first = list(open_dataset(files[0]).attrs.items())
     final = list(open_dataset(files[-1]).attrs.items())
@@ -548,33 +542,32 @@ def make_xr_dataset(
     else:
         global_attrs = {}
 
-    lons = df.filter(regex=re.compile('lon', re.IGNORECASE))
-    lats = df.filter(regex=re.compile('lat', re.IGNORECASE))
-    depths = df.filter(regex=re.compile('depth', re.IGNORECASE))
-    times = df.filter(regex=re.compile('time_dt64', re.IGNORECASE))
-    dives = df.filter(regex=re.compile('dive', re.IGNORECASE))
+    lons = df.filter(regex=re.compile("lon", re.IGNORECASE))
+    lats = df.filter(regex=re.compile("lat", re.IGNORECASE))
+    depths = df.filter(regex=re.compile("depth", re.IGNORECASE))
+    times = df.filter(regex=re.compile("time_dt64", re.IGNORECASE))
+    dives = df.filter(regex=re.compile("dive", re.IGNORECASE))
 
-    now = str(Timestamp('today'))[:19]
+    now = str(Timestamp("today"))[:19]
     history = (
-        '[{}] imported data with GliderTools.load.seaglider_'
-        'basestation_netCDFs;\n'
+        "[{}] imported data with GliderTools.load.seaglider_" "basestation_netCDFs;\n"
     ).format(now)
 
     global_attrs.update(attrs)
     global_attrs.update(
         {
-            'date_created': now,
-            'number_of_dives': dives.max().max() // 1,
-            'files': str([f.split('/')[-1] for f in files]),
-            'time_coverage_start': str(times.min().min()),
-            'time_coverage_end': str(times.max().max()),
-            'geospatial_vertical_min': depths.min().min(),
-            'geospatial_vertical_max': depths.max().max(),
-            'geospatial_lat_min': lats.min().min(),
-            'geospatial_lat_max': lats.max().max(),
-            'geospatial_lon_min': lons.min().min(),
-            'geospatial_lon_max': lons.max().max(),
-            'processing': history,
+            "date_created": now,
+            "number_of_dives": dives.max().max() // 1,
+            "files": str([f.split("/")[-1] for f in files]),
+            "time_coverage_start": str(times.min().min()),
+            "time_coverage_end": str(times.max().max()),
+            "geospatial_vertical_min": depths.min().min(),
+            "geospatial_vertical_max": depths.max().max(),
+            "geospatial_lat_min": lats.min().min(),
+            "geospatial_lat_max": lats.max().max(),
+            "geospatial_lon_min": lons.min().min(),
+            "geospatial_lon_max": lons.max().max(),
+            "processing": history,
         }
     )
 
@@ -585,14 +578,14 @@ def make_xr_dataset(
     coords = list(coords)
 
     for i, coord in enumerate(coords):
-        if 'time' in coord:
-            coords[i] = coord + '_dt64'
+        if "time" in coord:
+            coords[i] = coord + "_dt64"
 
     xds = (
         df.reset_index(drop=True)
         .to_xarray()
-        .drop('index')
-        .rename({'index': index_name})
+        .drop("index")
+        .rename({"index": index_name})
         .set_coords(coords)
         .assign_attrs(global_attrs)
     )
@@ -602,7 +595,7 @@ def make_xr_dataset(
         for key in xds.variables:
             attrs = get_var_attrs(files[mid], key)
             if attrs is not None:
-                attrs.pop('coordinates', None)
+                attrs.pop("coordinates", None)
                 xds[key].attrs = attrs
 
     return xds
