@@ -13,14 +13,14 @@ def calc_physics(
     dives,
     depth,
     spike_window=3,
-    spike_method='minmax',
+    spike_method="minmax",
     iqr=1.5,
     depth_threshold=400,
     mask_frac=0.2,
     savitzky_golay_window=11,
     savitzky_golay_order=2,
     verbose=True,
-    name='Physics Variable',
+    name="Physics Variable",
 ):
     """
     A standard setup for processing physics variables (temperature, salinity).
@@ -34,11 +34,12 @@ def calc_physics(
     """
 
     from numpy import array, isnan
+
     from .cleaning import (
-        savitzky_golay,
         despike,
-        outlier_bounds_iqr,
         horizontal_diff_outliers,
+        outlier_bounds_iqr,
+        savitzky_golay,
     )
 
     # an interpolation step is added so that no nans are created.
@@ -48,7 +49,7 @@ def calc_physics(
     x = array(dives)
     y = array(depth)
     z = array(variable)
-    printv(verbose, '\n' + '=' * 50 + '\n{}:'.format(name))
+    printv(verbose, "\n" + "=" * 50 + "\n{}:".format(name))
 
     if iqr:
         nans_before = isnan(z).sum()
@@ -57,14 +58,14 @@ def calc_physics(
         n_masked = nans_after - nans_before
         printv(
             verbose,
-            '\tRemoving outliers with IQR * {}: {} obs'.format(iqr, n_masked),
+            "\tRemoving outliers with IQR * {}: {} obs".format(iqr, n_masked),
         )
 
     if spike_window:
         z = despike(z, spike_window, spike_method)[0]
         printv(
             verbose,
-            '\tRemoving spikes with rolling median (spike window={})'.format(
+            "\tRemoving spikes with rolling median (spike window={})".format(
                 spike_window
             ),
         )
@@ -73,23 +74,21 @@ def calc_physics(
         z = horizontal_diff_outliers(x, y, z, iqr, depth_threshold, mask_frac)
         printv(
             verbose,
-            (
-                '\tRemoving horizontal outliers '
-                '(fraction={}, multiplier={})'
-            ).format(mask_frac, iqr),
+            ("\tRemoving horizontal outliers " "(fraction={}, multiplier={})").format(
+                mask_frac, iqr
+            ),
         )
 
     if savitzky_golay_window:
         printv(
             verbose,
-            (
-                '\tSmoothing with Savitzky-Golay filter '
-                '(window={}, order={})'
-            ).format(savitzky_golay_window, savitzky_golay_order),
+            ("\tSmoothing with Savitzky-Golay filter " "(window={}, order={})").format(
+                savitzky_golay_window, savitzky_golay_order
+            ),
         )
         z = savitzky_golay(z, savitzky_golay_window, savitzky_golay_order)
 
-    z = transfer_nc_attrs(getframe(), var, z, '_processed')
+    z = transfer_nc_attrs(getframe(), var, z, "_processed")
 
     return z
 
@@ -101,7 +100,7 @@ def calc_oxygen(
     temperature,
     auto_conversion=True,
     spike_window=7,
-    spike_method='median',
+    spike_method="median",
     savitzky_golay_window=0,
     savitzky_golay_order=2,
     verbose=True,
@@ -153,16 +152,17 @@ def calc_oxygen(
 
     """
 
-    from numpy import isnan, abs, array, ones, c_, median
-    from .cleaning import outlier_bounds_iqr, despike, savitzky_golay
     import seawater as sw
+    from numpy import abs, array, c_, isnan, median, ones
     from pandas import Series
 
+    from .cleaning import despike, outlier_bounds_iqr, savitzky_golay
+
     var = o2raw.copy()  # metdata preservation
     if isinstance(o2raw, Series):
         name = o2raw.name
     else:
-        name = 'Oxygen'
+        name = "Oxygen"
     o2raw = array(o2raw)
     pressure = array(pressure)
     temperature = array(temperature)
@@ -172,23 +172,20 @@ def calc_oxygen(
         o2raw, _ = despike(o2raw, spike_window, spike_method)
         printv(
             verbose,
-            '\n' + '=' * 50 + '\n{}:\n'
-            '\tSmoothing data with despiking algorithm:\n\t'
-            '    spike identification (spike window={})'
-            ''.format(name, spike_window),
+            "\n" + "=" * 50 + "\n{}:\n"
+            "\tSmoothing data with despiking algorithm:\n\t"
+            "    spike identification (spike window={})"
+            "".format(name, spike_window),
         )
 
     if savitzky_golay_window:
         printv(
             verbose,
-            (
-                '\tSmoothing with Savitzky-Golay filter '
-                '(window={}, order={})'
-            ).format(savitzky_golay_window, savitzky_golay_order),
-        )
-        o2raw = savitzky_golay(
-            o2raw, savitzky_golay_window, savitzky_golay_order
+            ("\tSmoothing with Savitzky-Golay filter " "(window={}, order={})").format(
+                savitzky_golay_window, savitzky_golay_order
+            ),
         )
+        o2raw = savitzky_golay(o2raw, savitzky_golay_window, savitzky_golay_order)
 
     o2sat = sw.satO2(salinity, temperature)
     density = sw.dens(salinity, temperature, pressure)
@@ -222,34 +219,34 @@ def calc_oxygen(
             printv(
                 verbose,
                 (
-                    'Oxygen unit could not be estimated automatically. '
-                    'Do the unit conversion on the raw data before '
-                    'passing it to the function. \n'
-                    'Below is some info to help you\n'
-                    '    µmol/l > µmol/kg * 1.025\n'
-                    '    µmol/l > ml/l * 44.66\n'
-                    '    µmol/l > mg/l * 31.25'
+                    "Oxygen unit could not be estimated automatically. "
+                    "Do the unit conversion on the raw data before "
+                    "passing it to the function. \n"
+                    "Below is some info to help you\n"
+                    "    µmol/l > µmol/kg * 1.025\n"
+                    "    µmol/l > ml/l * 44.66\n"
+                    "    µmol/l > mg/l * 31.25"
                 ),
             )
         # otherwise do the conversion
         else:
             unit_idx = ratio_diffs.argmin()
             if unit_idx == 0:
-                unit = 'mL/L'
+                unit = "mL/L"
                 o2mll = array(o2raw)
             elif unit_idx == 2:
-                unit = 'mg/L'
+                unit = "mg/L"
                 o2mll = array(o2raw) / 31.25 * (density / 1000)
             elif unit_idx == 1:
-                unit = 'umol/kg'
+                unit = "umol/kg"
                 o2mll = array(o2raw) / 44.66 * (density / 1000)
             else:
-                printv(verbose, 'Difference is {}'.format(ratio_diffs))
-            printv(verbose, '\tUnits automatically detected {}'.format(unit))
+                printv(verbose, "Difference is {}".format(ratio_diffs))
+            printv(verbose, "\tUnits automatically detected {}".format(unit))
             if ratio_diffs.min() > 5:
                 print(
-                    '\tWARNING: Confirm units mannually as near the '
-                    'confidence threshold'
+                    "\tWARNING: Confirm units mannually as near the "
+                    "confidence threshold"
                 )
         o2aou = o2sat - o2mll
         o2pct = o2mll / o2sat * 100
@@ -258,37 +255,37 @@ def calc_oxygen(
             getframe(),
             var,
             o2mll,
-            'o2mll',
-            units='mL/L',
-            comment='',
-            standard_name='dissolved_oxygen',
+            "o2mll",
+            units="mL/L",
+            comment="",
+            standard_name="dissolved_oxygen",
         )
         o2aou = transfer_nc_attrs(
             getframe(),
             var,
             o2mll,
-            'o2aou',
-            units='mL/L',
-            comment='',
-            standard_name='aparent_oxygen_utilisation',
+            "o2aou",
+            units="mL/L",
+            comment="",
+            standard_name="aparent_oxygen_utilisation",
         )
         o2pct = transfer_nc_attrs(
             getframe(),
             var,
             o2mll,
-            'o2pct',
-            units='percent',
-            comment='',
-            standard_name='theoretical_oxgen_saturation',
+            "o2pct",
+            units="percent",
+            comment="",
+            standard_name="theoretical_oxgen_saturation",
         )
 
         return o2mll, o2pct, o2aou
 
     else:
         print(
-            'No oxygen conversion applied - user '
-            'must impliment before or after running '
-            'the cleaning functions.'
+            "No oxygen conversion applied - user "
+            "must impliment before or after running "
+            "the cleaning functions."
         )
 
 
@@ -302,11 +299,11 @@ def calc_backscatter(
     dark_count,
     scale_factor,
     spike_window=7,
-    spike_method='median',
+    spike_method="median",
     iqr=3,
     profiles_ref_depth=300,
     deep_multiplier=1,
-    deep_method='median',
+    deep_method="median",
     return_figure=False,
     verbose=True,
 ):
@@ -400,10 +397,11 @@ def calc_backscatter(
 
 
     """
-    from numpy import array, nan, count_nonzero, unique, isnan
+    from numpy import array, count_nonzero, isnan, nan, unique
     from pandas import Series
-    from . import optics as op
+
     from . import flo_functions as ff
+    from . import optics as op
     from .cleaning import despike, despiking_report, outlier_bounds_iqr
 
     var = bb_raw.copy()  # metadata preservation
@@ -413,7 +411,7 @@ def calc_backscatter(
     tempC = array(tempC)
     salt = array(salt)
 
-    name = 'bb{:.0f}'.format(wavelength)
+    name = "bb{:.0f}".format(wavelength)
     theta = 124  # factory set angle of optical sensors
     xfactor = 1.076  # for theta 124
     # Values taken from Sullivan et al. (2013) & Slade and Boss (2015)
@@ -424,7 +422,7 @@ def calc_backscatter(
 
     dive_count = count_nonzero(unique(dives))
 
-    printv(verbose, '\n' + '=' * 50 + '\n{}:'.format(name))
+    printv(verbose, "\n" + "=" * 50 + "\n{}:".format(name))
 
     if iqr:
 
@@ -434,14 +432,12 @@ def calc_backscatter(
         n_masked = nans_after - nans_before
         printv(
             verbose,
-            '\tRemoving outliers with IQR * {}: {} obs'.format(iqr, n_masked),
+            "\tRemoving outliers with IQR * {}: {} obs".format(iqr, n_masked),
         )
 
     printv(
         verbose,
-        '\tMask bad profiles based on deep values (depth={}m)'.format(
-            ref_depth
-        ),
+        "\tMask bad profiles based on deep values (depth={}m)".format(ref_depth),
     )
     bad_profiles = op.find_bad_profiles(
         dives, depth, bb_raw, ref_depth, stdev_multiplier, method
@@ -452,44 +448,44 @@ def calc_backscatter(
 
     printv(
         verbose,
-        '\tNumber of bad profiles = {}/{}'.format(bad_count, dive_count),
+        "\tNumber of bad profiles = {}/{}".format(bad_count, dive_count),
     )
-    printv(verbose, '\tZhang et al. (2009) correction')
+    printv(verbose, "\tZhang et al. (2009) correction")
     beta = ff.flo_scale_and_offset(bb_raw, dark_count, scale_factor)
     bbp = ff.flo_bback_total(beta, tempC, salt, theta, wavelength, xfactor)
 
     # This is from .Briggs et al. (2011)
-    printv(verbose, '\tDark count correction')
+    printv(verbose, "\tDark count correction")
     bbp = op.backscatter_dark_count(bbp, depth)
 
     printv(
         verbose,
-        '\tSpike identification (spike window={})'.format(spike_window),
+        "\tSpike identification (spike window={})".format(spike_window),
     )
-    baseline, spikes = despike(bbp, spike_window, spike_method='median')
-    baseline = Series(baseline, name='bb{:.0f}'.format(wavelength))
+    baseline, spikes = despike(bbp, spike_window, spike_method="median")
+    baseline = Series(baseline, name="bb{:.0f}".format(wavelength))
 
     baseline = transfer_nc_attrs(
         getframe(),
         var,
         baseline,
-        name + '_baseline',
-        units='units',
-        standard_name='backscatter',
+        name + "_baseline",
+        units="units",
+        standard_name="backscatter",
     )
     spikes = transfer_nc_attrs(
         getframe(),
         var,
         spikes,
-        name + '_spikes',
-        units='units',
-        standard_name='backscatter',
+        name + "_spikes",
+        units="units",
+        standard_name="backscatter",
     )
 
     if not return_figure:
         return baseline, spikes
     else:
-        printv(verbose, '\tGenerating figure for despiking report')
+        printv(verbose, "\tGenerating figure for despiking report")
         fig = despiking_report(dives, depth, bbp, baseline, spikes, name=name)
 
         return baseline, spikes, fig
@@ -506,12 +502,12 @@ def calc_fluorescence(
     dark_count,
     scale_factor,
     spike_window=7,
-    spike_method='median',
+    spike_method="median",
     night_day_group=True,
     sunrise_sunset_offset=1,
     profiles_ref_depth=300,
     deep_multiplier=1,
-    deep_method='median',
+    deep_method="median",
     return_figure=False,
     verbose=True,
 ):
@@ -597,7 +593,8 @@ def calc_fluorescence(
 
     """
 
-    from numpy import array, nan, count_nonzero, unique
+    from numpy import array, count_nonzero, nan, unique
+
     from . import optics as op
     from .cleaning import despike, despiking_report
 
@@ -616,8 +613,8 @@ def calc_fluorescence(
     printv(
         verbose,
         (
-            '\n' + '=' * 50 + '\nFluorescence\n\tMask bad profiles based on '
-            'deep values (ref depth={}m)'
+            "\n" + "=" * 50 + "\nFluorescence\n\tMask bad profiles based on "
+            "deep values (ref depth={}m)"
         ).format(ref_depth),
     )
     bad_profiles = op.find_bad_profiles(
@@ -629,17 +626,17 @@ def calc_fluorescence(
     dive_count = count_nonzero(unique(dives))
     printv(
         verbose,
-        '\tNumber of bad profiles = {}/{}'.format(bad_count, dive_count),
+        "\tNumber of bad profiles = {}/{}".format(bad_count, dive_count),
     )
 
-    printv(verbose, '\tDark count correction')
+    printv(verbose, "\tDark count correction")
     flr_raw -= dark_count
     flr_dark = op.fluorescence_dark_count(flr_raw, depth)
     flr_dark[flr_dark < 0] = nan
 
-    baseline, spikes = despike(flr_dark, spike_window, spike_method='median')
+    baseline, spikes = despike(flr_dark, spike_window, spike_method="median")
 
-    printv(verbose, '\tQuenching correction')
+    printv(verbose, "\tQuenching correction")
     quench_corrected, quench_layer = op.quenching_correction(
         baseline,
         bbp,
@@ -654,39 +651,37 @@ def calc_fluorescence(
 
     printv(
         verbose,
-        '\tSpike identification (spike window={})'.format(spike_window),
+        "\tSpike identification (spike window={})".format(spike_window),
     )
 
     baseline = transfer_nc_attrs(
         getframe(),
         var,
         baseline,
-        'FLR_baseline',
-        units='RFU',
-        standard_name='',
+        "FLR_baseline",
+        units="RFU",
+        standard_name="",
     )
     quench_corrected = transfer_nc_attrs(
         getframe(),
         var,
         quench_corrected,
-        'FLR_quench_corrected',
-        units='RFU',
-        standard_name='fluorescence',
+        "FLR_quench_corrected",
+        units="RFU",
+        standard_name="fluorescence",
     )
     quench_layer = transfer_nc_attrs(
         getframe(),
         var,
         quench_layer,
-        'quenching_layer',
-        units='',
-        standard_name='',
-        comment='',
+        "quenching_layer",
+        units="",
+        standard_name="",
+        comment="",
     )
 
     if return_figure:
-        printv(
-            verbose, '\tGenerating figures for despiking and quenching report'
-        )
+        printv(verbose, "\tGenerating figures for despiking and quenching report")
         figs = (
             despiking_report(
                 dives,
@@ -694,7 +689,7 @@ def calc_fluorescence(
                 flr_raw,
                 baseline.data,
                 spikes,
-                name='Fluorescence',
+                name="Fluorescence",
             ),
         )
         figs += (
@@ -750,6 +745,7 @@ def calc_par(
     """
 
     from numpy import array
+
     from . import optics as op
 
     var = par_raw.copy()  # metdata presrevation
@@ -758,31 +754,29 @@ def calc_par(
     depth = array(depth)
     time = array(time)
 
-    printv(verbose, '\n' + '=' * 50 + '\nPAR\n\tDark correction')
+    printv(verbose, "\n" + "=" * 50 + "\nPAR\n\tDark correction")
 
     # dark correction for par
-    par_scaled = op.par_scaling(
-        par_raw, scale_factor_wet_uEm2s, sensor_output_mV
-    )
+    par_scaled = op.par_scaling(par_raw, scale_factor_wet_uEm2s, sensor_output_mV)
     par_dark = op.par_dark_count(par_scaled, dives, depth, time)
-    printv(verbose, '\tFitting exponential curve to data')
+    printv(verbose, "\tFitting exponential curve to data")
     par_filled = op.par_fill_surface(
         par_dark, dives, depth, max_curve_depth=curve_max_depth
     )
     par_filled[par_filled < 0] = 0
 
     attrs = dict(
-        standard_name='photosynthetically_available_radiation',
-        units='uE/m2/s2',
-        comment='',
+        standard_name="photosynthetically_available_radiation",
+        units="uE/m2/s2",
+        comment="",
     )
     par_filled = transfer_nc_attrs(
-        getframe(), var, par_filled, 'PAR_processed', **attrs
+        getframe(), var, par_filled, "PAR_processed", **attrs
     )
     par_filled = par_filled.fillna(0)
 
     return par_filled
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
